# pnap-payments-api
Payments API are currently designed to fetch Transactions only.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.1
- Package version: 1.0.3
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://phoenixnap.com/](https://phoenixnap.com/)

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

You can install this package directly from the [Python Package Index](https://pypi.org/) using:

```sh
$ pip install pnap_payments_api
```

Then import the package:
```python
import pnap_payments_api
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import pnap_payments_api
```

```python

import time
import pnap_payments_api
from pnap_payments_api.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.phoenixnap.com/payments/v1
# See configuration.py for a list of all supported configuration parameters.
configuration = pnap_payments_api.Configuration(
    host = "https://api.phoenixnap.com/payments/v1"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

configuration.access_token = os.environ["ACCESS_TOKEN"]


# Enter a context with an instance of the API client
with pnap_payments_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = pnap_payments_api.TransactionsApi(api_client)
    transaction_id = '0a1b2c3d4f5g6h7i8j9k' # str | The transaction identifier.

    try:
        # Get Transaction.
        api_response = api_instance.transaction_id_get(transaction_id)
        print("The response of TransactionsApi->transaction_id_get:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling TransactionsApi->transaction_id_get: %s\n" % e)

```

To generate a token using the [python-keycloak](https://pypi.org/project/python-keycloak/) library:
```python
from keycloak import KeycloakOpenID

clientId = "YOUR_CLIENT_ID"
clientSecret = "YOUR_CLIENT_SECRET"
serverUrl = "https://auth.phoenixnap.com/auth/"
realmName = "BMC"
grantType = "client_credentials"

keycloakOpenId =  KeycloakOpenID(server_url=serverUrl,
                        realm_name=realmName,
                        client_id=clientId,
                        client_secret_key=clientSecret)

ACCESS_TOKEN = keycloakOpenId.token(grant_type=grantType)['access_token']


## Documentation for API Endpoints

All URIs are relative to *https://api.phoenixnap.com/payments/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*TransactionsApi* | [**transaction_id_get**](docs/TransactionsApi.md#transaction_id_get) | **GET** /transactions/{transactionId} | Get Transaction.
*TransactionsApi* | [**transactions_get**](docs/TransactionsApi.md#transactions_get) | **GET** /transactions | Get Transactions.


## Documentation For Models

 - [CardPaymentMethodDetails](docs/CardPaymentMethodDetails.md)
 - [Error](docs/Error.md)
 - [PaginatedResponse](docs/PaginatedResponse.md)
 - [PaginatedTransactions](docs/PaginatedTransactions.md)
 - [Transaction](docs/Transaction.md)
 - [TransactionMetadata](docs/TransactionMetadata.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="OAuth2"></a>
### OAuth2

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: 
 - **transactions**: Grants full access to transactions.
 - **transactions.read**: Grants read only access to transactions.


## Author

support@phoenixnap.com

